Trait PartsWrite
trait PartsWrite: fmt::Write
A sink that supports annotating parts of the string with Parts.
Associated Types
type SubPartsWrite: TraitBound { trait_: Path { path: "PartsWrite", id: Id(9), args: None }, generic_params: [], modifier: None } + TraitBound { trait_: Path { path: "Sized", id: Id(11), args: None }, generic_params: [], modifier: Maybe }
Required Methods
fn with_part<impl FnMut(&mut Self::SubPartsWrite) -> fmt::Result: FnMut(&mut <Self as >::SubPartsWrite) -> fmt::Result>(self: &mut Self, part: Part, f: impl FnMut(&mut <Self as >::SubPartsWrite) -> Result) -> ResultAnnotates all strings written by the closure with the given
Part.
Implementors
impl<W: fmt::Write + ?Sized> PartsWrite for CoreWriteAsPartsWrite<W>